# pytautulli [![Build Status](https://travis-ci.org/ludeeus/pytautulli.svg?branch=master)](https://travis-ci.org/ludeeus/pytautulli) [![PyPI version](https://badge.fury.io/py/pytautulli.svg)](https://badge.fury.io/py/pytautulli)

_A python module to get information from Tautulli._

## Notes

This module require API key from Tautulli.  

## Install

```bash
pip install pytautulli
```

Look at the file `example.py` for a usage example.
